"""Package metadata/info"""

__all__ = ("__title__", "__description__", "__pkgroot__", "__version__")
__title__ = "crapy"
__description__ = "Make python worse"
__pkgroot__ = __file__.replace("__about__.py", "").rstrip("/\\")
__version__ = "0.0.3"
